abacusnbody.analysis
====================

power_spectrum module
---------------------

.. automodule:: abacusnbody.analysis.power_spectrum
   :members:
   :undoc-members:
   :show-inheritance:

tpcf_corrfunc module
--------------------

.. automodule:: abacusnbody.analysis.tpcf_corrfunc
   :members:
   :undoc-members:
   :show-inheritance:

tsc module
----------

.. automodule:: abacusnbody.analysis.tsc
   :members:
   :undoc-members:
   :show-inheritance:
